==> qtjambi-qt3drender-6.2.4-sources.jar: io/qt/qt3d/render/QMultiSampleAntiAliasing.java <==
package io.qt.qt3d.render;


/**
 * <p>Enable multisample antialiasing</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qmultisampleantialiasing.html">Qt3DRender::QMultiSampleAntiAliasing</a></p>
 */
public class QMultiSampleAntiAliasing extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMultiSampleAntiAliasing.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QMultiSampleAntiAliasing(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QMultiSampleAntiAliasing() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qmultisampleantialiasing.html#QMultiSampleAntiAliasing">Qt3DRender::QMultiSampleAntiAliasing::QMultiSampleAntiAliasing(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QMultiSampleAntiAliasing(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMultiSampleAntiAliasing instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QMultiSampleAntiAliasing(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QMultiSampleAntiAliasing(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QMultiSampleAntiAliasing instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.0-sources.jar: io/qt/qt3d/render/QMultiSampleAntiAliasing.java <==
package io.qt.qt3d.render;


/**
 * <p>Enable multisample antialiasing</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qmultisampleantialiasing.html">Qt3DRender::QMultiSampleAntiAliasing</a></p>
 */
public class QMultiSampleAntiAliasing extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMultiSampleAntiAliasing.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QMultiSampleAntiAliasing(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QMultiSampleAntiAliasing() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qmultisampleantialiasing.html#QMultiSampleAntiAliasing">Qt3DRender::QMultiSampleAntiAliasing::QMultiSampleAntiAliasing(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QMultiSampleAntiAliasing(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMultiSampleAntiAliasing instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QMultiSampleAntiAliasing(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QMultiSampleAntiAliasing(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QMultiSampleAntiAliasing instance, QDeclarativeConstructor constructor);
    
}
